@@ -4,7 +4,7 @@ use warnings;
 use strict;
 
 
-our $VERSION = '0.1601';
+our $VERSION = '0.1700';
 
 use parent 'Games::Solitaire::Verify::Base';
 
@@ -222,6 +222,11 @@ sub fast_s
 {
     my @_t_nums = ('0', (map { $_->{t} } @card_nums));
 
+sub get_ranks_strings
+{
+    return \@_t_nums;
+}
+
 sub rank_to_string
 {
     my ($class, $rank) = @_;
@@ -264,7 +269,7 @@ Solitaire card.
 
 =head1 VERSION
 
-version 0.1601
+version 0.1700
 
 =head1 SYNOPSIS
 
@@ -340,6 +345,12 @@ A cached string representation. (Use with care).
 
 Converts the rank to a string.
 
+=head2 my [@ranks] = $class->get_ranks_strings()
+
+Returns an (effectively constant) array reference of rank strings.
+
+( Added in version 0.17 .)
+
 =head2 $card->is_flipped()
 
 Determines if the card is flipped.
