@@ -4,7 +4,7 @@ use warnings;
 use strict;
 
 
-our $VERSION = '0.1601';
+our $VERSION = '0.1700';
 
 use parent 'Games::Solitaire::Verify::Base';
 
@@ -109,17 +109,22 @@ sub clone
 }
 
 
+sub append_cards
+{
+    my ($S, $c) = @_;
+    push @{$S->_cards()}, @$c;
+    $S->_recalc;
+    return;
+}
+
+
 sub append
 {
     my ($self, $more_cards) = @_;
 
     my $more_copy = $more_cards->clone();
 
-    push @{$self->_cards()}, @{$more_copy->_cards()};
-
-    $self->_recalc;
-
-    return;
+    return $self->append_cards($more_copy->_cards);
 }
 
 
@@ -147,6 +152,18 @@ sub pop
 }
 
 
+sub popN
+{
+    my ($S, $c) = @_;
+
+    my @r = splice(@{$S->_cards()}, -$c);
+
+    $S->_recalc;
+
+    return \@r;
+}
+
+
 sub _recalc
 {
     my $self = shift;
@@ -184,7 +201,7 @@ columns that are composed of a sequence of cards.
 
 =head1 VERSION
 
-version 0.1601
+version 0.1700
 
 =head1 SYNOPSIS
 
@@ -221,9 +238,16 @@ Returns the top card.
 
 Returns a clone of the column.
 
+=head2 $base_column->append_cards(\@cards)
+
+Appends the cards in the argument array reference to the column.
+
+( Added in version 0.17 .)
+
 =head2 $base_column->append($column_with_more_cards)
 
-Appends the column $column_with_more_cards to $base_column .
+Appends the column $column_with_more_cards to $base_column . B<NOTE:>
+append_cards() is faster.
 
 =head2 $column->push($card)
 
@@ -233,6 +257,13 @@ Appends a single card to the top of the column.
 
 Pops a card from the top of the column and returns it.
 
+=head2 my [@cards] = $column->popN($num_cards)
+
+Pops $num_cards cards from the top of the column and returns them (as an
+array reference) in their original order in the column.
+
+( Added in version 0.17 .)
+
 =head2 $column->to_string()
 
 Converts to a string.
