@@ -4,7 +4,7 @@ use warnings;
 use strict;
 
 
-our $VERSION = '0.1601';
+our $VERSION = '0.1700';
 
 use parent 'Games::Solitaire::Verify::Base';
 
@@ -13,11 +13,20 @@ use Games::Solitaire::Verify::Card;
 
 use List::Util qw(first);
 
+# _s is the string.
 __PACKAGE__->mk_acc_ref([qw(
     _num_decks
     _founds
+    _s
     )]);
 
+# Suits sequence:
+my @SS = (@{Games::Solitaire::Verify::Card->get_suits_seq()});
+# Reverse.
+my %RS = (map { $SS[$_] => $_ } (0 .. $#SS));
+# Ranks
+my @R = (@{Games::Solitaire::Verify::Card->get_ranks_strings()});
+
 
 sub _input_from_string
 {
@@ -36,7 +45,7 @@ sub _input_from_string
     {
         my @founds_strings = ($1, $2, $3, $4);
 
-        foreach my $suit (@{$self->_get_suits_seq()})
+        foreach my $suit (@SS)
         {
             $self->assign($suit, 0,
                 Games::Solitaire::Verify::Card->calc_rank_with_0(
@@ -62,25 +71,21 @@ sub _init
         +{
             map
             { $_ => [(0) x $self->_num_decks()], }
-            @{$self->_get_suits_seq()}
+            @SS
         }
     );
 
+    $self->_s($self->_init_s);
+
     if (exists($args->{string}))
     {
         $self->_input_from_string($args->{string});
     }
 
+
     return;
 }
 
-sub _get_suits_seq
-{
-    my $class = shift;
-
-    return Games::Solitaire::Verify::Card->get_suits_seq();
-}
-
 
 sub value
 {
@@ -96,6 +101,8 @@ sub assign
 
     $self->_founds()->{$suit}->[$idx] = $rank;
 
+    # Replace the rank in place.
+    substr($self->{_s}, (length('Foundations:') + 3) + ($RS{$suit} << 2), 1, $R[$rank]);
     return;
 }
 
@@ -104,7 +111,7 @@ sub increment
 {
     my ($self, $suit, $idx) = @_;
 
-    $self->_founds()->{$suit}->[$idx]++;
+    substr($self->{_s}, (length('Foundations:') + 3) + ($RS{$suit} << 2), 1, $R[++($self->_founds()->{$suit}->[$idx])]);
 
     return;
 }
@@ -115,25 +122,25 @@ sub _foundations_strings
     my $self = shift;
 
     return [
-        map {
-            sprintf(qq{ %s-%s},
-                $_,
-                Games::Solitaire::Verify::Card->rank_to_string(
-                    $self->value($_, 0)
-                ),
-            )
-        }
-        (@{$self->_get_suits_seq()})
     ];
 }
 
 sub to_string
 {
-    my $self = shift;
+    return $_[0]->_s;
+}
+
+sub _init_s
+{
+    my $S = shift;
 
     return   "Foundations:"
-           . join("", @{$self->_foundations_strings()})
-           ;
+    . join("",
+        map {
+            " $_-".  $R[ $S->value($_, 0) ]
+        }
+        @SS
+    );
 }
 
 
@@ -149,7 +156,7 @@ sub clone
             }
         );
 
-    foreach my $suit (@{$self->_get_suits_seq()})
+    foreach my $suit (@SS)
     {
         foreach my $deck_idx (0 .. ($self->_num_decks()-1))
         {
@@ -178,7 +185,7 @@ foundations (or home-cells) in a Solitaire game.
 
 =head1 VERSION
 
-version 0.1601
+version 0.1700
 
 =head1 SYNOPSIS
 
