@@ -4,7 +4,7 @@ use warnings;
 use strict;
 
 
-our $VERSION = '0.1601';
+our $VERSION = '0.1700';
 
 use parent 'Games::Solitaire::Verify::Base';
 
@@ -13,9 +13,11 @@ use Games::Solitaire::Verify::Card;
 
 use List::Util qw(first);
 
+# _s is the string.
 __PACKAGE__->mk_acc_ref([qw(
     _count
     _cells
+    _s
     )]);
 
 
@@ -63,6 +65,8 @@ sub _init
 
     $self->_count($args->{count});
 
+    $self->_s('Freecells:' . ('    ' x $self->_count));
+
     $self->_cells([(undef) x $self->_count()]);
 
     if (exists($args->{string}))
@@ -111,6 +115,7 @@ sub assign
     my ($self, $idx, $card) = @_;
 
     $self->_cells()->[$idx] = $card;
+    substr($self->{_s}, length('Freecells:')+($idx << 2)+2,2,(defined($card) ? $card->fast_s : '  '));
 
     return;
 }
@@ -118,17 +123,8 @@ sub assign
 
 sub to_string
 {
-    my $self = shift;
-
-    my $ret = "Freecells:" . (($self->count() == 0) ? "" :
-        join("",
-            map { "  " . (defined($_) ? $_->fast_s() : "  ") }
-            map { $self->cell($_) }
-            (0 .. ($self->count()-1))
-        ));
-    $ret =~ s# +\z##;
-
-    return $ret;
+    (my $r = $_[0]->{_s}) =~ s# +\z##;
+    return $r;
 }
 
 
@@ -146,7 +142,7 @@ sub clear
 {
     my ($self, $pos) = @_;
 
-    undef($self->_cells()->[$pos]);
+    $self->assign($pos, undef());
 
     return;
 }
@@ -204,7 +200,7 @@ Freecells in games such as Freecell, Baker's Game, or Seahaven Towers
 
 =head1 VERSION
 
-version 0.1601
+version 0.1700
 
 =head1 SYNOPSIS
 
@@ -225,7 +221,7 @@ Returns the card in the freecell with the index $index .
 =head2 $self->assign($index, $card)
 
 Sets the card in the freecell with the index $index to $card, which
-should be a L<Games::Solitaire::Verify::Card> object.
+should be a L<Games::Solitaire::Verify::Card> object or undef.
 
 =head2 $self->to_string()
 
