@@ -6,7 +6,7 @@ use strict;
 use 5.008;
 
 
-our $VERSION = '0.1601';
+our $VERSION = '0.1700';
 
 use parent 'Games::Solitaire::Verify::Solution::Base';
 
@@ -21,33 +21,14 @@ sub _init
 {
     my ($self, $args) = @_;
 
-    $self->_variant($args->{variant});
+    $self->SUPER::_init($args);
 
-    if ($self->_variant() eq "custom")
-    {
-        $self->_variant_params($args->{variant_params});
-    }
-    $self->_i($args->{input_fh});
-    $self->_state(undef);
-    $self->_ln(0);
+    $self->_st(undef);
     $self->_reached_end(0);
 
     return 0;
 }
 
-sub _calc_variant_args
-{
-    my $self = shift;
-
-    my @ret;
-    if ($self->_variant() eq "custom")
-    {
-        push @ret, ('variant_params' => $self->_variant_params());
-    }
-    push @ret, (variant => $self->_variant());
-    return \@ret;
-}
-
 sub _read_state
 {
     my $self = shift;
@@ -67,20 +48,20 @@ sub _read_state
     }
 
 
-    if (!defined($self->_state()))
+    if (!defined($self->_st()))
     {
-        my $new_state = Games::Solitaire::Verify::State->new(
+        $self->_st(
+            Games::Solitaire::Verify::State->new(
                 {
                     string => $str,
-                    @{$self->_calc_variant_args()},
+                    @{$self->_V},
                 }
-            );
-
-        $self->_state($new_state);
+            )
+        );
     }
     else
     {
-        if ($self->_state()->to_string() ne $str)
+        if ($self->_st()->to_string() ne $str)
         {
             die "States don't match";
         }
@@ -135,7 +116,7 @@ sub _apply_move
 {
     my $self = shift;
 
-    if (my $verdict = $self->_state()->verify_and_perform_move($self->_move()))
+    if (my $verdict = $self->_st()->verify_and_perform_move($self->_move()))
     {
         Games::Solitaire::Verify::Exception::VerifyMove->throw(
             error => "Wrong Move",
@@ -204,7 +185,7 @@ of Freecell Solver (or a similar solve)
 
 =head1 VERSION
 
-version 0.1601
+version 0.1700
 
 =head1 SYNOPSIS
 
