@@ -7,13 +7,16 @@ use warnings;
 use parent 'Games::Solitaire::Verify::Base';
 
 # "_ln" is line number
+# "_st" is the "state" (or board/layout).
 # "_i" is input filehandle.
+# "_V" is short for variant arguments.
 __PACKAGE__->mk_acc_ref([qw(
+    _V
     _i
     _ln
     _variant
     _variant_params
-    _state
+    _st
     _move
     _reached_end
     )]);
@@ -26,12 +29,50 @@ sub _l
     # We use this instead of the accessor for speed.
     $s->{_ln}++;
 
-    my $ret;
-    if (defined ( $ret = scalar (readline($s->{_i})) ))
-    {
-        $ret =~ s# +(\n?)\z#$1#;
-    }
-    return $ret;
+    return shift(@{$s->{_i}});
+}
+
+sub _calc_variant_args
+{
+    my $self = shift;
+
+    return [
+        variant => $self->_variant(),
+        (
+            ($self->_variant eq 'custom')
+            ? ('variant_params' => $self->_variant_params())
+            : ()
+        )
+    ];
+}
+
+sub _init
+{
+    my ($self, $args) = @_;
+
+    $self->_i(
+        [ split /^/ms, do {
+                local $/;
+                my $t = readline($args->{input_fh});
+                $t =~ s/ +$//gms;
+                $t;
+            }
+    ]);
+    $self->_ln(0);
+
+    $self->_variant($args->{variant});
+
+    $self->_variant_params(
+        $self->_variant eq 'custom'
+        ? $args->{variant_params}
+        : Games::Solitaire::Verify::VariantsMap->get_variant_by_id(
+            $self->_variant()
+        )
+    );
+
+    $self->_V($self->_calc_variant_args());
+
+    return;
 }
 
 1;
@@ -49,7 +90,7 @@ all Games::Solitaire::Verify::Solution::* classes.
 
 =head1 VERSION
 
-version 0.1601
+version 0.1700
 
 =head1 AUTHOR
 
