@@ -4,7 +4,7 @@ use warnings;
 use strict;
 
 
-our $VERSION = '0.1601';
+our $VERSION = '0.1700';
 
 use parent 'Games::Solitaire::Verify::Solution::Base';
 
@@ -29,23 +29,9 @@ sub _init
 {
     my ($self, $args) = @_;
 
-    $self->_variant($args->{variant});
+    $self->SUPER::_init($args);
 
-    if ($self->_variant() eq "custom")
-    {
-        $self->_variant_params($args->{variant_params});
-    }
-    else
-    {
-        $self->_variant_params(
-            Games::Solitaire::Verify::VariantsMap->get_variant_by_id(
-                $self->_variant()
-            )
-        );
-    }
-    $self->_i($args->{input_fh});
-    $self->_state(undef);
-    $self->_ln(0);
+    $self->_st(undef);
     $self->_reached_end(0);
     $self->_output_fh($args->{output_fh});
 
@@ -56,7 +42,7 @@ sub _out
 {
     my ($self, $text) = @_;
 
-    print { $self->_output_fh() } $text;
+    $self->_output_fh()->print($text);
 
     return;
 }
@@ -68,19 +54,6 @@ sub _out_line
     return $self->_out($line);
 }
 
-sub _calc_variant_args
-{
-    my $self = shift;
-
-    my @ret;
-    if ($self->_variant() eq "custom")
-    {
-        push @ret, ('variant_params' => $self->_variant_params());
-    }
-    push @ret, (variant => $self->_variant());
-    return \@ret;
-}
-
 sub _assign_read_new_state
 {
     my ($self, $str) = @_;
@@ -88,23 +61,23 @@ sub _assign_read_new_state
     my $new_state = Games::Solitaire::Verify::State->new(
             {
                 string => $str,
-                @{$self->_calc_variant_args()},
+                @{$self->_V},
             }
         );
 
-    if (!defined($self->_state()))
+    if (!defined($self->_st()))
     {
         # Do nothing.
 
     }
     else
     {
-        if ($self->_state()->to_string() ne $str)
+        if ($self->_st()->to_string() ne $str)
         {
             die "States don't match";
         }
     }
-    $self->_state($new_state);
+    $self->_st($new_state);
 
     return;
 }
@@ -225,18 +198,18 @@ sub _apply_move
         my @empty_fc_indexes;
         my @empty_stack_indexes;
 
-        foreach my $idx (0 .. ($self->_state->num_freecells()-1))
+        foreach my $idx (0 .. ($self->_st->num_freecells()-1))
         {
-            if (!defined($self->_state->get_freecell($idx)))
+            if (!defined($self->_st->get_freecell($idx)))
             {
                 push @empty_fc_indexes, $idx;
             }
         }
 
-        foreach my $idx (0 .. ($self->_state->num_columns()-1))
+        foreach my $idx (0 .. ($self->_st->num_columns()-1))
         {
             if (($idx != $ultimate_dest) && ($idx != $ultimate_source) &&
-                (! $self->_state->get_column($idx)->len()))
+                (! $self->_st->get_column($idx)->len()))
             {
                 push @empty_stack_indexes, $idx;
             }
@@ -267,7 +240,7 @@ sub _apply_move
         my $past_first_output_state_promise = sub {
             $self->_out(
                 "\n"
-                . $self->_state->to_string
+                . $self->_st->to_string
                 . "\n\n====================\n\n"
             );
 
@@ -282,7 +255,7 @@ sub _apply_move
 
             $self->_out_line($move_line."\n");
 
-            if (my $verdict = $self->_state()->verify_and_perform_move(
+            if (my $verdict = $self->_st()->verify_and_perform_move(
                     Games::Solitaire::Verify::Move->new(
                         {
                             fcs_string => $move_line,
@@ -388,7 +361,7 @@ sub _apply_move
     else
     {
         $self->_out_line( $self->_move_line . "\n" );
-        if (my $verdict = $self->_state()->verify_and_perform_move($self->_move()))
+        if (my $verdict = $self->_st()->verify_and_perform_move($self->_move()))
         {
             Games::Solitaire::Verify::Exception::VerifyMove->throw(
                 error => "Wrong Move",
@@ -459,7 +432,7 @@ moves.
 
 =head1 VERSION
 
-version 0.1601
+version 0.1700
 
 =head1 SYNOPSIS
 
