@@ -6,19 +6,19 @@ use warnings;
 use parent 'Games::Solitaire::Verify::Solution::ExpandMultiCardMoves';
 
 
-our $VERSION = '0.1601';
+our $VERSION = '0.1700';
 
 sub _assign_read_new_state
 {
     my ($self, $str) = @_;
 
-    if (!defined($self->_state()))
+    if (!defined($self->_st()))
     {
-        $self->_state(
+        $self->_st(
             Games::Solitaire::Verify::State->new(
                 {
                     string => $str,
-                    @{$self->_calc_variant_args()},
+                    @{$self->_V},
                 }
             )
         );
@@ -43,7 +43,7 @@ laxer expansion.
 
 =head1 VERSION
 
-version 0.1601
+version 0.1700
 
 =head1 SYNOPSIS
 
