@@ -4,7 +4,7 @@ use warnings;
 use strict;
 
 
-our $VERSION = '0.1601';
+our $VERSION = '0.1700';
 
 use parent 'Games::Solitaire::Verify::Base';
 
@@ -482,16 +482,20 @@ sub verify_and_perform_move
 {
     my ($self, $move) = @_;
 
-    $self->_temp_move($move);
-
-    my $ret = $self->_verify_and_perform_move_main();
-
-    $self->_temp_move(undef());
-
-    return $ret;
+    if (my $method = $self->can("_mv_" . $move->source_type . "_to_" . $move->dest_type))
+    {
+        $self->_temp_move($move);
+        my $ret = $method->($self);
+        $self->_temp_move(undef());
+        return $ret;
+    }
+    else
+    {
+        die "Cannot handle this move type";
+    }
 }
 
-sub _perform_move__stack_to_foundation
+sub _mv_stack_to_foundation
 {
     my $self = shift;
 
@@ -524,7 +528,7 @@ sub _perform_move__stack_to_foundation
     }
 }
 
-sub _perform_move__stack_seq_to_foundation
+sub _mv_stack_seq_to_foundation
 {
     my $self = shift;
 
@@ -590,7 +594,7 @@ sub _perform_move__stack_seq_to_foundation
     }
 }
 
-sub _perform_move__stack_to_freecell
+sub _mv_stack_to_freecell
 {
     my $self = shift;
     my $move = $self->_temp_move();
@@ -619,7 +623,7 @@ sub _perform_move__stack_to_freecell
     return 0;
 }
 
-sub _perform_move__stack_to_stack
+sub _mv_stack_to_stack
 {
     my $self = shift;
     my $move = $self->_temp_move();
@@ -628,7 +632,11 @@ sub _perform_move__stack_to_stack
     my $dest = $move->dest();
     my $num_cards = $move->num_cards();
 
-    my $source_len = $self->get_column($source)->len() ;
+    # Source column
+    my $sc = $self->get_column($source);
+    my $dc = $self->get_column($dest);
+
+    my $source_len = $sc->len();
 
     if ($source_len < $num_cards)
     {
@@ -650,7 +658,7 @@ sub _perform_move__stack_to_stack
 
     if (my $verdict = $self->_can_put_on_column(
             $dest,
-            $self->get_column($source)->pos($source_len-$num_cards)
+            $sc->pos($source_len-$num_cards)
         ))
     {
         return $verdict;
@@ -661,7 +669,7 @@ sub _perform_move__stack_to_stack
 
     if ($num_seq_components > $self->_calc_max_sequence_move(
             {
-                to_empty => ($self->get_column($dest)->len() == 0),
+                to_empty => ($dc->len() == 0),
             }
             ))
     {
@@ -672,23 +680,12 @@ sub _perform_move__stack_to_stack
     }
 
     # Now let's actually move them.
-    my @cards;
-    foreach my $i (1 .. $num_cards)
-    {
-        push @cards, $self->get_column($source)->pop();
-    }
-    $self->get_column($dest)->append(
-        Games::Solitaire::Verify::Column->new(
-            {
-                cards => [reverse @cards],
-            }
-        )
-    );
+    $dc->append_cards( $sc->popN($num_cards) );
 
     return 0;
 }
 
-sub _perform_move__freecell_to_foundation
+sub _mv_freecell_to_foundation
 {
     my $self = shift;
     my $move = $self->_temp_move();
@@ -728,7 +725,7 @@ sub _perform_move__freecell_to_foundation
     }
 }
 
-sub _perform_move__freecell_to_stack
+sub _mv_freecell_to_stack
 {
     my $self = shift;
     my $move = $self->_temp_move();
@@ -756,27 +753,6 @@ sub _perform_move__freecell_to_stack
     return 0;
 }
 
-sub _verify_and_perform_move_main
-{
-    my $self = shift;
-
-    my $move = $self->_temp_move();
-
-    my $src = $move->source_type();
-    my $dest = $move->dest_type();
-
-    my $method = $self->can("_perform_move__${src}_to_${dest}");
-
-    if ($method)
-    {
-        return $method->($self);
-    }
-    else
-    {
-        die "Cannot handle this move type";
-    }
-}
-
 
 sub to_string
 {
@@ -806,7 +782,7 @@ states (or positions) of the entire board.
 
 =head1 VERSION
 
-version 0.1601
+version 0.1700
 
 =head1 SYNOPSIS
 
